package com.ynet.life.util;

import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import java.util.Properties;
import java.util.logging.Level;
import javax.servlet.ServletContext;
import org.eclipse.birt.core.exception.BirtException;
import org.eclipse.birt.core.framework.Platform;
import org.eclipse.birt.core.framework.PlatformServletContext;
import org.eclipse.birt.report.engine.api.EngineConfig;
import org.eclipse.birt.report.engine.api.IReportEngine;
import org.eclipse.birt.report.engine.api.IReportEngineFactory;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/BirtEngine.class */
public class BirtEngine {
    private static IReportEngine birtEngine = null;
    private static Properties configProps = new Properties();

    public static synchronized void initBirtConfig() {
        String logDirectory = LifeStandard.getSelfDefineSettingsValue("birtlogDirectory");
        String logLevel = LifeStandard.getSelfDefineSettingsValue("birtlogLevel");
        configProps.put("logDirectory", logDirectory == null ? "" : logDirectory);
        configProps.put("logLevel", logLevel == null ? "OFF" : logLevel);
    }

    public static synchronized IReportEngine getBirtEngine(ServletContext sc) {
        if (birtEngine == null) {
            EngineConfig config = new EngineConfig();
            if (configProps != null) {
                String logLevel = configProps.getProperty("logLevel");
                Level level = Level.OFF;
                if ("SEVERE".equalsIgnoreCase(logLevel)) {
                    level = Level.SEVERE;
                } else if ("WARNING".equalsIgnoreCase(logLevel)) {
                    level = Level.WARNING;
                } else if ("INFO".equalsIgnoreCase(logLevel)) {
                    level = Level.INFO;
                } else if ("CONFIG".equalsIgnoreCase(logLevel)) {
                    level = Level.CONFIG;
                } else if ("FINE".equalsIgnoreCase(logLevel)) {
                    level = Level.FINE;
                } else if ("FINER".equalsIgnoreCase(logLevel)) {
                    level = Level.FINER;
                } else if ("FINEST".equalsIgnoreCase(logLevel)) {
                    level = Level.FINEST;
                } else if ("OFF".equalsIgnoreCase(logLevel)) {
                    level = Level.OFF;
                }
                config.setLogConfig(configProps.getProperty("logDirectory"), level);
            }
            config.setEngineHome("");
            config.setPlatformContext(new PlatformServletContext(sc));
            try {
                Platform.startup(config);
            } catch (BirtException bte) {
                Trace.logError("LifeThird", bte.getMessage(), bte);
            }
            birtEngine = ((IReportEngineFactory) Platform.createFactoryObject("org.eclipse.birt.report.engine.ReportEngineFactory")).createReportEngine(config);
        }
        return birtEngine;
    }

    public static synchronized void destroyBirtEngine() {
        if (birtEngine == null) {
            return;
        }
        birtEngine.destroy();
        Platform.shutdown();
        birtEngine = null;
    }

    public Object clone() throws CloneNotSupportedException {
        throw new CloneNotSupportedException();
    }
}
